Crate kcr_gateway_networking_k8s_io

Crate kcr_gateway_networking_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the gateway.networking.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

gateway.networking.k8s.io/v1

  • BackendTLSPolicy
  • GatewayClass
  • Gateway
  • GRPCRoute
  • HTTPRoute
  • ListenerSet
  • ReferenceGrant
  • TCPRoute
  • TLSRoute
  • UDPRoute

gateway.networking.k8s.io/v1alpha2

  • BackendLBPolicy
  • GRPCRoute
  • ReferenceGrant
  • TCPRoute
  • TLSRoute
  • UDPRoute

gateway.networking.k8s.io/v1alpha3

  • BackendTLSPolicy
  • TLSRoute

gateway.networking.k8s.io/v1beta1

  • GatewayClass
  • Gateway
  • HTTPRoute
  • ReferenceGrant

Modules

v1
v1alpha2
v1alpha3
v1beta1