This crate contains kube-rs compatible bindings for Kubernetes custom resources for the gateway.networking.k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
gateway.networking.k8s.io/v1
BackendTLSPolicyGatewayClassGatewayGRPCRouteHTTPRouteListenerSetReferenceGrantTCPRouteTLSRouteUDPRoute
gateway.networking.k8s.io/v1alpha2
BackendLBPolicyGRPCRouteReferenceGrantTCPRouteTLSRouteUDPRoute
gateway.networking.k8s.io/v1alpha3
BackendTLSPolicyTLSRoute
gateway.networking.k8s.io/v1beta1
GatewayClassGatewayHTTPRouteReferenceGrant